@@ -25,7 +25,7 @@ class AWSMarkThis(Db):
         for row in self.namedselect(qry, (style,)):
             return json.loads(row['positions'])
 
-        return None
+        return {}
 
     def style_delete(self, style):
         '''deletes info for style'''
@@ -34,11 +34,11 @@ class AWSMarkThis(Db):
     def sheet_insert(self, rows):
         '''Insert sheets.
         rows is a list of tuples.  Each row has the following items in order
-        sheetid, owner, title, style, answers_csv '''
+        sheetid, owner, title, style, answers_csv, positions '''
 
         qry = '''INSERT into sheet
-                 (sheetid, owner, title, style, answers_csv, created_at)
-                 VALUES(%s, %s, %s, %s, %s, NOW())'''
+                 (sheetid, owner, title, style, answers_csv, positions, created_at)
+                 VALUES(%s, %s, %s, %s, %s, %s, NOW())'''
 
         return self.executemany(qry, rows)
 
